/***************************************************************************
                          dlg_selectemail.h  -  description
                             -------------------
    begin                : Sun Oct 27 2002
    copyright            : (C) 2003 by Troy Corbin Jr.
    email                : tcorbin@users.sf.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DLG_SELECTEMAIL_H
#define DLG_SELECTEMAIL_H

#include <tqwidget.h>
#include <kdialogbase.h>

/**
  *@author Troy Corbin Jr.
  */

class resource;
class TQVBox;
class TQLineEdit;

class dlg_selectemail : public KDialogBase
{
	TQ_OBJECT
  
	public:
										dlg_selectemail(TQWidget *parent, resource *Rsrc );
										~dlg_selectemail();

	signals:
		void						valuesChanged( void );

	protected slots:
		void						changeValue( void );

	private:
		resource				*myResource;

		TQVBox						*BOX_Parent;
			TQLineEdit				*EDIT_Email;
};

#endif
